#!/usr/bin/env python
# SPDX-FileCopyrightText: 2017-2024 Luis Falcón <falcon@gnuhealth.org>
# SPDX-FileCopyrightText: 2017-2024 GNU Solidario <health@gnusolidario.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

#########################################################################
# Thalamus, the GNU Health Federation Message and Authentication Server #
#                                                                       #
#             Thalamus is part of the GNU Health project                #
#                   https://www.gnuhealth.org                           #
#########################################################################
#                           Thalamus package                            #
#                       __init__.py declaration file                    #
#########################################################################



#!/usr/bin/env python3

# SPDX-FileCopyrightText: 2017-2024 GNU Solidario <health@gnusolidario.org>
# SPDX-FileCopyrightText: 2017-2024 Luis Falcón <falcon@gnuhealth.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

import json
import psycopg2
import logging


# Modify to meet your needs
PG_URI = "postgresql:///federation"

try:
    conn = psycopg2.connect(PG_URI)
except Exception as err:
    logging.error(f"Exception {err=}, {type(err)=}")

people_file = open('people.json', 'r')
people_data = json.load(people_file)

pols_file = open('pols.json', 'r')
pols_data = json.load(pols_file)

personal_docs_file = open('personal_docs.json', 'r')
personal_docs_data = json.load(personal_docs_file)


doc_file = open('newborn.jpg', 'rb')
document = doc_file.read()


doc_id = "8789981f-4e31-48d5-8eb8-1774dac8b8f6"
cur = conn.cursor()


for person in people_data:
    id = person['id']
    print("Inserting", id)
    cur.execute(
        "INSERT INTO people (ID, DATA) VALUES (%(id)s, \
        %(data)s) ON CONFLICT DO NOTHING",
        {'id': id, 'data': json.dumps(person)})
    conn.commit()


for pol in pols_data:
    id = pol['id']
    book = pol['book']
    print("Inserting", id, book)
    cur.execute(
        "INSERT INTO pols (ID, BOOK, DATA) VALUES (%(id)s, \
        %(book)s, %(data)s) ON CONFLICT DO NOTHING",
        {'id': id, 'book': book, 'data': json.dumps(pol)})
    conn.commit()


# Insert personal document for Ana Betz
for doc in personal_docs_data:
    print("Importing PERSONAL DOCS...", doc)
    id = doc['id']
    fedacct = doc['fedacct']
    pol = doc['pol']
    cur.execute(
                "INSERT INTO personal_docs (ID, FEDACCT, POL, DATA) \
                VALUES (%(id)s, %(fedacct)s, %(pol)s, %(data)s)  \
                ON CONFLICT DO NOTHING",
                {'id': id, 'fedacct': fedacct, 'pol': pol,
                 'data': json.dumps(doc)})
    conn.commit()


# Update specific personal doc from demo newborn picture
cur.execute(
    "UPDATE personal_docs SET document = %s where id = %s",
    (document, doc_id))

conn.commit()



#!/usr/bin/env python
# SPDX-FileCopyrightText: 2017-2024 Luis Falcón <falcon@gnuhealth.org>
# SPDX-FileCopyrightText: 2017-2024 GNU Solidario <health@gnusolidario.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

#########################################################################
# Thalamus, the GNU Health Federation Message and Authentication Server #
#                                                                       #
#             Thalamus is part of the GNU Health project                #
#                   https://www.gnuhealth.org                           #
#########################################################################
#                           Thalamus package                            #
#                       setup.py: Setuptools file                       #
#########################################################################

from setuptools import setup, find_packages

long_desc = open("README.rst").read()

version = open("version").read().strip()

setup(name='thalamus',
      version=version,
      description='The GNU Health Federation Message'
                  ' and Authentication Server',
      keywords='health API REST',
      long_description=long_desc,
      platforms='any',
      author='GNU Solidario',
      author_email='health@gnusolidario.org',
      url='https://www.gnuhealth.org',
      download_url='http://ftp.gnu.org/gnu/health',
      classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Flask',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Healthcare Industry',
        'License :: OSI Approved :: '
        'GNU General Public License v3 or later (GPLv3+)',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Topic :: Scientific/Engineering :: Medical Science Apps.',
        ],
      install_requires=[
        "flask",
        "flask-cors"
        "flask_httpauth",
        "flask_restful",
        "flask_wtf",
        "psycopg2-binary",
        "bcrypt",
      ],
      packages=find_packages(),
      include_package_data=True,
      zip_safe=False,
      )
